
%==============================================================================
%   EMClass.cls
%   LaTeX Class for the series Ensaios Matemáticos of the Brazilian Mathematical Society
%==============================================================================
%   Yunelsy Nápoles Alvarez -- ynapolez@gmail.com - https://www.yna-latex.com/
%==============================================================================

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{EMClassColection}[2022/05/16 LaTeX class for Ensaios Matemáticos]





%==============================================================================
%========================  COMMANDS FOR FRONT MATTER ================================
%==============================================================================
\let\@startpage\@empty
\let\@theyear\@empty
\let\@thevol\@empty
\let\@thedoi\@empty
\let\@theabstract\@empty
\let\@theKeywords\@empty
\let\@theMSC\@empty
\let\@thefinalpage\@empty

\newcommand{\@EditorialBoard}{%
\include{EditorialBoard}}


\newcommand{\@copyrightPage}{%
\include{copyrightPage}}



\newcommand{\@titlepage}{%
\thispagestyle{empty}

\noindent\resizebox{!}{2.1mm}{\sf SOCIEDADE BRASILEIRA DE MATEM\'ATICA} \hfill {\footnotesize \sf ENSAIOS MATEM\'ATICOS}

\hfill{\footnotesize \sf \@theyear, Volume {\bf \@thevol}, \@startpage--\pageref{LastPage}} % o LastPage no referencia a página em branco caso necessário. 

\hfill{\footnotesize \sf\@thedoi}

\vspace{-0.805cm}\noindent \includegraphics[width=2.5cm,height=1.9cm]{Figures/SBMLogo}
\vskip 0.4in
\noindent\hspace*{-0.15cm}\begin{tikzpicture}
\node[text width=\textwidth,align=flush left] (titulo) {\huge\textbf{\@title}\endgraf};
\node[text width=\textwidth,align=flush left,below=of titulo] (autor) {\Large\textbf{\@author}\endgraf};
\end{tikzpicture}
{\renewcommand*{\@makefnmark}{}%drop the number in the next footnote
\footnotetext{\@theMSC}}
\vskip 0.2in

\@theabstract

\bigskip\noindent\@theKeywords
}



\newcommand{\Cover}{}% 

\newcommand{\Publications}{\pagestyle{empty}
\include{Publications}% publications of the Brazilian Mathematical Society
\cleardoublepage
}




%==============================================================================
% =========================== AUTHORS OPTION ====================================
%==============================================================================
% 
\renewcommand{\baselinestretch}{1.0}
\RequirePackage{graphicx} % to define the right path of the figures in both options
\RequirePackage{tikz}
\usetikzlibrary{positioning,shapes.misc}






\DeclareOption{authors}{%
\graphicspath{{ColoredFigures/}{Figures/}}%folder for colored figures
\AtBeginDocument%
{\RequirePackage{url}
\urlstyle{same} % to have same font in url
\RequirePackage[hidelinks,breaklinks,bookmarksopen=true]{hyperref}
%%%%%%%%%%%%
\setcounter{page}{\@startpage}
\@titlepage
\newpage
\setcounter{footnote}{0}                          
}
}


%==============================================================================
% ============================== EDITORS OPTION ===================================
%==============================================================================
% 


\DeclareOption{editors}{%
\graphicspath{{GrayscaleFigures/}{Figures/}} %folder for grayscale figures
%%%%%%%%%%%%%%%%
\AtBeginDocument{%
\RequirePackage{url}
\urlstyle{same} % to have same font in url
\RequirePackage[hidelinks,breaklinks,bookmarksopen=true]{hyperref}
%%%%%%%%%%%%%%
\RequirePackage[a4,center,cam,info]{crop}
\RequirePackage{ifoddpage}
\setcounter{page}{\@startpage}
\@titlepage
\newpage
\setcounter{footnote}{0}                          
}
%%%%%%%%%%%%%%%%%
\AtEndDocument{%
\checkoddpage
\@ifoddpage{\newpage~\thispagestyle{empty}}{}
}
}





\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[10pt, twoside]{article}



\RequirePackage{lastpage}


%==============================================================================
%================================== MEDIDAS =====================================
%==============================================================================

\RequirePackage[dvips=false,pdftex=false,vtex=false]{geometry}
\geometry{%twoside,%
paperwidth=16.0cm, paperheight=22.95cm, left=2.7cm, right=2.0cm, top=1.5cm, bottom=0.9cm, includehead, includefoot}





%==============================================================================
%============================  HEADERS / FOOTERS ====================================
%==============================================================================
\newcommand{\@theshortauthor}{}

\let\MakeUppercase=\relax 

\def\ps@headings{%
      \let\@oddfoot\@empty
	 \let\@evenfoot\@empty
      \def\@evenhead{\sffamily\normalsize\thepage\hfil\@theshortauthor}%
      \def\@oddhead{\sffamily\normalsize\@title\hfil\thepage}%
      \let\@mkboth\markboth
}


\pagestyle{headings}






\newcommand\firstpage[1]{\renewcommand\@startpage{#1}}
\newcommand\shortauthor[1]{\renewcommand\@theshortauthor{#1}}
\newcommand\volume[1]{\renewcommand\@thevol{#1}}
\newcommand\Year[1]{\renewcommand\@theyear{#1}}
\newcommand\doi[1]{\renewcommand\@thedoi{\url{#1}}}
\renewcommand\abstract[1]{\renewcommand\@theabstract{\noindent\textbf{Abstract.~}#1}}
\newcommand\MSC[2]{\renewcommand\@theMSC{\textbf{#1~Mathematics Subject Classification:}~#2.}}
\newcommand\Keywords[1]{\renewcommand\@theKeywords{\textbf{Keywords.}~#1.}}
%\newcommand\finalpage{\renewcommand\@thefinalpage{\pageref{LastPage}}}


\newcommand{\address}[1]{#1}
\newcommand{\email}[1]{\href{mailto:#1}{#1}}
\newcommand{\webpage}[1]{\url{#1}}










\RequirePackage{amsthm}
\def\th@plain{%
  \thm@notefont{}% same as heading font
  \itshape % body font
}
\def\th@definition{%
  \thm@notefont{}% same as heading font
  \normalfont % body font
}











\endinput




